@@ -1,7 +1,5 @@
 r"""
-pysak is a simple, powerful and clean python common function library.
-
-test
+pysak is a simple, powerful and clean python common function library..
 
 Github Repository: https://github.com/1Gbps/pysak
 """
