@@ -2,6 +2,7 @@ import pysak
 import time
 
 
+# 获取当前时刻指定长度的时间戳  10位~17位
 def getTimestamp(length=10):
     """
         获取当前时刻指定长度的时间戳  10位~17位
@@ -24,6 +25,12 @@ def getTimestamp(length=10):
     return timestamp
 
 
-def getDate():
+# 获取当前Date
+def getDate(format="%Y-%m-%d %H:%M:%S"):
+    """
+    获取当前Date
+    @param format: 日期格式
+    @return:
+    """
     ltime = time.localtime(getTimestamp(10))
-    return time.strftime("%Y-%m-%d %H:%M:%S", ltime)
+    return time.strftime(format, ltime)
